@@ -37,11 +37,11 @@ __author__ = 'Iurii KIBALIN'
 __copyright__   = "Copyright 2022, "
 __credits__ = ["Iurii KIBALIN", "Andrew SAZONOV", "Arsen GOUKASSOV"]
 __license__ = "GPL"
-__version__ = "0.6.5"
+__version__ = "0.6.7"
 __maintainer__ = "Iurii KIBALIN"
 __email__ = "iurii.kibalin@cea.fr"
 __status__ = "Development"
-__date__ = "15.04.2022"
+__date__ = "14.10.2022"
 name = "cryspy"
 
 
@@ -147,6 +147,8 @@ from cryspy.H_functions_global.function_1_cryspy_objects import \
     L_GLOBAL_CLASS, L_DATA_CLASS, L_LOOP_CLASS, L_ITEM_CLASS, load_packages, \
     add_package, packages, delete_package, L_FUNCTION_ADD
 
+from cryspy.H_functions_global.powder_experiments import report_powder_experiments
+
 from cryspy.procedure_rhochi.rhochi import rhochi_rietveld_refinement, \
     rhochi_rietveld_refinement_with_parameters, \
     rhochi_no_refinement, rhochi_inversed_hessian
@@ -160,6 +162,7 @@ from cryspy.procedure_mempy.mempy import  mempy_magnetization_density_reconstruc
 
 
 
+
 def repr_function(function, flag_long: bool = False):
     ls_out = []
     name = function.__name__
@@ -258,6 +261,7 @@ L_FUNCTION = [
     repr_function,
     magnetization_ellipsoid_by_u_ij,
     report_main_axes_of_magnetization_ellipsoids,
+    report_powder_experiments,
     rhochi_rietveld_refinement, 
     rhochi_rietveld_refinement_with_parameters, 
     rhochi_no_refinement,
