@@ -83,7 +83,8 @@ def calc_chi_sq_for_pd_by_dictionary(
     ttheta_zs = ttheta - offset_ttheta
     flags_offset_ttheta = dict_pd["flags_offset_ttheta"]
     if flag_dict:
-        dict_in_out["ttheta"] = ttheta_zs  
+        dict_in_out["ttheta"] = ttheta
+        dict_in_out["ttheta_corrected"] = ttheta_zs  
         dict_in_out["excluded_points"] = excluded_points 
 
 
@@ -240,7 +241,7 @@ def calc_chi_sq_for_pd_by_dictionary(
 
         flag_ttheta_hkl = flag_sthovl_hkl or flags_wavelength
         ttheta_hkl = 2*numpy.arcsin(sthovl_hkl*wavelength)
-        dict_in_out_phase["ttheta_hkl"] = ttheta_hkl
+        dict_in_out_phase["ttheta_hkl"] = ttheta_hkl + offset_ttheta
         if radiation[0].startswith("neutrons"):
             f_nucl, dder_f_nucl = calc_f_nucl_by_dictionary(
                 dict_crystal, dict_in_out_phase, flag_use_precalculated_data=flag_use_precalculated_data)
